import { QueryList, AfterViewChecked, AfterContentInit, ElementRef, OnDestroy, Renderer2, IterableDiffers } from '@angular/core';
import { Observable } from 'rxjs';
import { BootstrapSelectOptionDirective } from './bootstrapSelectOption.directive';
/**
 * Directive that wraps bootstrap select
 */
export declare class BootstrapSelectDirective implements AfterViewChecked, AfterContentInit, OnDestroy {
    private _element;
    private _iterableDiffers;
    private _renderer;
    /**
     * Indication that current code is running in browser
     */
    private _isBrowser;
    /**
     * Collection of items that are displayed in select
     */
    private _collection;
    /**
     * Object monitoring collection changes
     */
    private _differ;
    /**
     * Subject that is used for emitting changed values
     */
    private _selectChangedSubject;
    /**
     * Currently set value
     */
    private _value;
    /**
     * Indication that current bootstrap select is disabled
     */
    private _disabled;
    /**
     * Subscription for changes of content options
     */
    private _contentOptionsSubscription;
    /**
     * Sets collection of tracked items
     */
    collection: any[];
    /**
     * Indication that current bootstrap select is disabled
     */
    disabled: boolean;
    /**
     * Gets observable that is trigerred when select value changed
     */
    readonly selectChanged: Observable<any>;
    /**
     * Gets or sets value of select picker, any picker supported value
     */
    value: any;
    /**
     * Array of options that are in this select
     */
    contentOptions: QueryList<BootstrapSelectOptionDirective>;
    /**
     * Array of options that are as content in select
     */
    private readonly options;
    /**
     * Gets jQuery object for select picker
     */
    private readonly selector;
    constructor(_element: ElementRef, _iterableDiffers: IterableDiffers, platformId: Object, _renderer: Renderer2);
    /**
     * Runs after view was checked for changes
     */
    ngAfterViewChecked(): any;
    /**
     * Called when content was initialized
     */
    ngAfterContentInit(): void;
    /**
     * Called when component is destroyed
     */
    ngOnDestroy(): void;
    /**
     * Refresh visuals of bootstrap select from current HTML <select>
     */
    refresh(): void;
    /**
     * Convert bootstrap select value to real value
     */
    private _toValue;
    /**
     * Converts real value to bootstrap select value
     */
    private _fromValue;
}
